"
 COPYRIGHT (c) 2008 by eXept Software AG
              All Rights Reserved

 This software is furnished under a license and may be used
 only in accordance with the terms of that license and with the
 inclusion of the above copyright notice.   This software may not
 be provided or otherwise made available to, or used by, any
 other person.  No title to or ownership of the software is
 hereby transferred.
"
"{ Package: 'stx:libwidg' }"

Object subclass:#TranslatedSymbol
	instanceVariableNames:'symbol string'
	classVariableNames:''
	poolDictionaries:''
	category:'Views-Support'
!

!TranslatedSymbol class methodsFor:'documentation'!

copyright 
"
 COPYRIGHT (c) 2008 by eXept Software AG
              All Rights Reserved

 This software is furnished under a license and may be used
 only in accordance with the terms of that license and with the
 inclusion of the above copyright notice.   This software may not
 be provided or otherwise made available to, or used by, any
 other person.  No title to or ownership of the software is
 hereby transferred.
"
!

documentation
"
    Translated symbol contains both a symbol and a string.
    It represents itself as the string in ComboLists.

    It defines #asSymbol to show its underlying symbol.

    Use this class for ComboBoxes/PopUpLists with readable (and translated output),
    but returning language independent symbols.
    

    [author:]
        Stefan Vogel (stefan@zwerg)

    [instance variables:]
        symbol      Symbol      the symbol
        string      String      the string

    [class variables:]

    [see also:]

"
!

examples
"
                                                                                    [exBegin]
    |labelList top comboList|

    labelList := TranslatedSymbol collection:#(File Classes System Windows)
                                  withResources:Launcher classResources.

     top := StandardSystemView new.
     top extent:(300 @ 200).

     comboList := ComboListView in:top.
     comboList origin:(0.0 @ 0.0) corner:(1.0 @ 0.0).
     comboList bottomInset:(comboList preferredExtent y negated).

     comboList list:labelList.
     comboList action:[:selected | Transcript showCR:selected asSymbol].
     top open.
                                                                                     [exEnd]

"
! !

!TranslatedSymbol class methodsFor:'instance creation'!

collection:aCollectionOfSymbols withResources:resourcePack
    "create a colelction of translated symbols from aCollectionOfSymbols"

    ^ aCollectionOfSymbols collect:[:eachSymbol|
            self symbol:eachSymbol withResources:resourcePack
        ].


    "
      self collection:#(a File c) withResources:Launcher classResources
    "
!

symbol:aSymbol string:aString
    ^ self new symbol:aSymbol string:aString
!

symbol:aSymbol withResources:resourcePack
    "set a symbol that is resolved via the translations in resourcePack"

    ^ self new symbol:aSymbol string:(resourcePack string:aSymbol)

    "
      self symbol:#Hello withResources:Launcher classResources
    "
! !

!TranslatedSymbol methodsFor:'accessing'!

string
    ^ string
!

symbol
    ^ symbol
!

symbol:symbolArg string:stringArg 
    symbol := symbolArg.
    string := stringArg.
! !

!TranslatedSymbol methodsFor:'comparing'!

= aSymbolOrTranslatedSymbol
    "two TranslatedSymbols are equal, if they have the same symbol"

    aSymbolOrTranslatedSymbol isString ifTrue:[
        ^ symbol = aSymbolOrTranslatedSymbol.
    ].
    self species == aSymbolOrTranslatedSymbol species ifTrue:[
        ^ symbol = aSymbolOrTranslatedSymbol symbol
    ].
    ^ false

    "
        (TranslatedSymbol symbol:#hash string:'x') = #hash
        (TranslatedSymbol symbol:#hash string:'x') = 1
        (TranslatedSymbol symbol:#hash string:'x') = (TranslatedSymbol symbol:#hash string:'y')
    "
!

hash
    "two TranslatedSymbols are equal, if they have the same symbol"

    ^ symbol hash
! !

!TranslatedSymbol methodsFor:'converting'!

asString
    "answer the string aspect"

    ^ string
!

asSymbol
    "answer the symbol aspect"

    ^ symbol
! !

!TranslatedSymbol methodsFor:'printing'!

displayOn:aStream
    aStream 
        nextPutAll:self className;
        nextPut:$(.
    symbol printOn:aStream.
    aStream nextPutAll:'->'.
    string printOn:aStream.
    aStream nextPut:$).
!

displayOn:aGc x:x y:y opaque:opaque
    "copied from object, but do the ascent handling here"

    |yBaseline|

    yBaseline := y + aGc font ascent.
    opaque ifTrue:[
        aGc displayOpaqueString:string x:x y:yBaseline.
    ] ifFalse:[
        aGc displayString:string x:x y:yBaseline.
    ].
!

printString
    "this hast to be redefined to allow access from ComboLists via pressing the first character key"

    ^ string
!

widthOn:aGc
    ^ string widthOn:aGc
! !

!TranslatedSymbol class methodsFor:'documentation'!

version
    ^ '$Header: /cvs/stx/stx/libwidg/Attic/TranslatedSymbol.st,v 1.3 2008-06-23 16:01:47 stefan Exp $'
! !
